@@ -59,6 +59,8 @@ KItemListController::KItemListController(QObject* parent) :
 {
     connect(m_keyboardManager, SIGNAL(changeCurrentItem(QString,bool)),
             this, SLOT(slotChangeCurrentItem(QString,bool)));
+    connect(m_selectionManager, SIGNAL(currentChanged(int,int)),
+            m_keyboardManager, SLOT(slotCurrentChanged(int,int)));
 
     m_autoActivationTimer = new QTimer(this);
     m_autoActivationTimer->setSingleShot(true);
@@ -358,6 +360,13 @@ bool KItemListController::keyPressEvent(QKeyEvent* event)
         break;
     }
 
+    case Qt::Key_Escape:
+        if (m_selectionBehavior != SingleSelection) {
+            m_selectionManager->clearSelection();
+        }
+        m_keyboardManager->cancelSearch();
+        break;
+
     default:
         m_keyboardManager->addKeys(event->text());
         return false;
@@ -749,6 +758,8 @@ bool KItemListController::dragMoveEvent(QGraphicsSceneDragDropEvent* event, cons
         return false;
     }
 
+    event->acceptProposedAction();
+
     KItemListWidget* oldHoveredWidget = hoveredWidget();
 
     const QPointF pos = transform.map(event->pos());
